#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Union

import pydantic
from typing_extensions import Annotated

from foundry.v2.aip_agents.models._object_set_parameter_value_update import (
    ObjectSetParameterValueUpdate,
)  # NOQA
from foundry.v2.aip_agents.models._string_parameter_value import StringParameterValue

ParameterValueUpdate = Annotated[
    Union[StringParameterValue, ObjectSetParameterValueUpdate], pydantic.Field(discriminator="type")
]
"""
A value update for an [application variable](/docs/foundry/agent-studio/application-state/) generated by the Agent.
For `StringParameter` types, this will be the updated string value.
For `ObjectSetParameter` types, this will be a Resource Identifier (RID) for the updated object set.
"""
