#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from typing import Optional

from foundry._core import Auth
from foundry._core import Config


class OrchestrationClient:
    """
    The API client for the Orchestration Namespace.

    :param auth: Your auth configuration.
    :param hostname: Your Foundry hostname (for example, "myfoundry.palantirfoundry.com"). This can also include your API gateway service URI.
    :param config: Optionally specify the configuration for the HTTP session.
    """

    def __init__(
        self,
        auth: Auth,
        hostname: str,
        config: Optional[Config] = None,
    ):
        from foundry.v2.orchestration.build import BuildClient
        from foundry.v2.orchestration.schedule import ScheduleClient
        from foundry.v2.orchestration.schedule_version import ScheduleVersionClient

        self.Build = BuildClient(auth=auth, hostname=hostname, config=config)
        self.Schedule = ScheduleClient(auth=auth, hostname=hostname, config=config)
        self.ScheduleVersion = ScheduleVersionClient(auth=auth, hostname=hostname, config=config)
