#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

import pydantic

from foundry.v2.core.models._change_data_capture_configuration import (
    ChangeDataCaptureConfiguration,
)  # NOQA
from foundry.v2.core.models._field import Field
from foundry.v2.core.models._field_name import FieldName
from foundry.v2.streams.models._create_stream_request_stream_schema_dict import (
    CreateStreamRequestStreamSchemaDict,
)  # NOQA


class CreateStreamRequestStreamSchema(pydantic.BaseModel):
    """CreateStreamRequestStreamSchema"""

    key_field_names: Optional[List[FieldName]] = pydantic.Field(alias=str("keyFieldNames"), default=None)  # type: ignore[literal-required]

    """
    The names of the fields to be used as keys for partitioning records. These key fields are used to group
    all records with the same key into the same partition, to guarantee processing order of grouped records. These
    keys are not meant to uniquely identify records, and do not by themselves deduplicate records. To deduplicate
    records, provide a change data capture configuration for the schema.

    Key fields can only be of the following types:
    - Boolean
    - Byte
    - Date
    - Decimal
    - Integer
    - Long
    - Short
    - String
    - Timestamp

    For additional information on keys for Foundry streams, see the
    [streaming keys](/docs/foundry/building-pipelines/streaming-keys/) user documentation.
    """

    fields: List[Field]

    change_data_capture: Optional[ChangeDataCaptureConfiguration] = pydantic.Field(alias=str("changeDataCapture"), default=None)  # type: ignore[literal-required]

    model_config = {"extra": "allow", "populate_by_name": True}

    def to_dict(self) -> CreateStreamRequestStreamSchemaDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            CreateStreamRequestStreamSchemaDict, self.model_dump(by_alias=True, exclude_none=True)
        )
